==> onos-yang-serializers-xml-2.3-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/telinkinfoattributes/interfaceswitchingcapability/interfaceadjustmentcapability/MaxLspBandwidthKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkinfoattributes.interfaceswitchingcapability.interfaceadjustmentcapability;

import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of maxLspBandwidth.
 */
public class MaxLspBandwidthKeys implements KeyInfo<DefaultMaxLspBandwidth> {
    protected short priority;
    /**
     * Returns the attribute priority.
     *
     * @return priority value of priority
     */
    public short priority() {
        return priority;
    }

    /**
     * Sets the value to attribute priority.
     *
     * @param priority value of priority
     */
    public void priority(short priority) {
        this.priority = priority;
    }


    @Override
    public int hashCode() {
        return Objects.hash(priority);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof MaxLspBandwidthKeys) {
            MaxLspBandwidthKeys other = (MaxLspBandwidthKeys) obj;
            return
                Objects.equals(priority, other.priority);
        }
        return false;
    }
}

==> onos-yang-serializers-xml-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtietftetopology/rev20160317/yrtietftetopology/telinkinfoattributes/interfaceswitchingcapability/interfaceadjustmentcapability/MaxLspBandwidthKeys.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtietftetopology.rev20160317.yrtietftetopology.telinkinfoattributes.interfaceswitchingcapability.interfaceadjustmentcapability;

import org.onosproject.yang.model.KeyInfo;
import java.util.Objects;

/**
 * Represents the implementation of maxLspBandwidth.
 */
public class MaxLspBandwidthKeys implements KeyInfo<DefaultMaxLspBandwidth> {
    protected short priority;
    /**
     * Returns the attribute priority.
     *
     * @return priority value of priority
     */
    public short priority() {
        return priority;
    }

    /**
     * Sets the value to attribute priority.
     *
     * @param priority value of priority
     */
    public void priority(short priority) {
        this.priority = priority;
    }


    @Override
    public int hashCode() {
        return Objects.hash(priority);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof MaxLspBandwidthKeys) {
            MaxLspBandwidthKeys other = (MaxLspBandwidthKeys) obj;
            return
                Objects.deepEquals(priority, other.priority);
        }
        return false;
    }
}
